/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.spring;

import org.codehaus.activemq.broker.BrokerContainer;
import org.codehaus.activemq.broker.BrokerContainerFactory;
import org.springframework.core.io.Resource;

/**
 * A Spring implementatation of {@link BrokerContainerFactory} which uses an XML
 * deployment configuration file to load and configure a {@link BrokerContainer}
 *
 * @version $Revision: 1.1 $
 */
public class SpringBrokerContainerFactory implements BrokerContainerFactory {
    private Resource resource;


    /**
     * A static factory method that can be used in Spring config files using a factory method
     * mechanism to create a broker container easily.
     */
    public static BrokerContainer newInstance(Resource resource, String brokerName) {
        SpringBrokerContainerFactory factory = new SpringBrokerContainerFactory(resource);
        return factory.createBrokerContainer(brokerName);
    }

    public SpringBrokerContainerFactory() {
    }

    public SpringBrokerContainerFactory(Resource resource) {
        this.resource = resource;
    }

    public BrokerContainer createBrokerContainer(String brokerName) {
        ActiveMQBeanFactory beanFactory = new ActiveMQBeanFactory(brokerName, resource);
        return (BrokerContainer) beanFactory.getBean("broker");
    }

    // Properties
    //-------------------------------------------------------------------------
    public Resource getResource() {
        return resource;
    }

    public void setResource(Resource resource) {
        this.resource = resource;
    }
}
